BoundedSemilattice<T> mixin
A semilattice in which:
For all elements
xandyofA, both the least upper bound and greatest lower bound of the set{x, y}exist.
See also Semilattice
- Superclass constraints
- CommutativeMonoid<
T> - Semilattice<
T>
- CommutativeMonoid<
Properties
- empty → T
-
Return the identity element for this monoid.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asJoinPartialOrder(
Eq< T> eq) → PartialOrder<T> -
Given
Eq<T>, return aPartialOrder<T>using thecombineoperator ofSemilatticeto determine the partial ordering. This method assumescombinefunctions asjoin(that is, as an upper bound).inherited -
asMeetPartialOrder(
Eq< T> eq) → PartialOrder<T> -
Given
Eq<T>, return aPartialOrder<T>using thecombineoperator ofSemilatticeto determine the partial ordering. This method assumescombinefunctions asmeet(that is, as a lower bound).inherited -
combine(
T x, T y) → T -
Associative operation which combines two values.
inherited
-
combineN(
T a, int n) → T -
Return
a, sincecombine(a, a) == afor a semilattice (idempotent).override -
intercalate(
T middle) → Semigroup< T> -
Return a
Semigroupwhich insertsmiddlebetween each pair of elements.inherited -
isEmpty(
T a, Eq< T> eq) → bool -
Tests if
ais the identity (empty).inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverse(
) → BoundedSemilattice< T> -
Return a
BoundedSemilatticethat reverses the order.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
instance<
A> (A emptyValue, A f(A a1, A a2)) → BoundedSemilattice< A> -
Create a
BoundedSemilatticeinstance from the given function and empty value.override